#ifndef NT2_INCLUDE_FUNCTIONS_SBITS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SBITS_HPP_INCLUDED

#include <nt2/ieee/include/functions/sbits.hpp>

#endif
